document.addEventListener('DOMContentLoaded', async () => {
    const urlParams = new URLSearchParams(window.location.search);
    const bookId = urlParams.get('id');
    const bookDetails = document.getElementById('book-details');

    if (!bookId) {
        bookDetails.innerHTML = `
            <div class="col-12 text-center py-5">
                <h2 class="text-danger">Nieprawidłowe ID książki</h2>
                <a href="/" class="btn btn-gothic mt-3">Powrót do strony głównej</a>
            </div>
        `;
        return;
    }

    try {
        const response = await fetch(`/api/ksiazki/${bookId}`);
        if (!response.ok) {
            throw new Error(`Status: ${response.status}`);
        }
        const book = await response.json();

        document.getElementById('book-title').textContent = book.tytul;
        document.getElementById('book-author').textContent = `Autor: ${book.autor}`;
        document.getElementById('book-price').textContent = `Cena: ${book.cena} PLN`;
        document.getElementById('book-description').textContent = book.opis;
        document.getElementById('book-cover').src = book.obraz_url;

        // Dodaj obsługę przycisku "Dodaj do koszyka"
        document.querySelector('.btn-gothic').addEventListener('click', async () => {
            const token = localStorage.getItem('token');
            if (!token) {
                alert('Musisz być zalogowany, aby dodać książkę do koszyka');
                window.location.href = '/login.html';
                return;
            }

            try {
                const response = await fetch('/api/add-to-cart', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                        'Authorization': `Bearer ${token}`
                    },
                    body: JSON.stringify({
                        book_id: parseInt(bookId),
                        quantity: 1
                    })
                });

                if (response.ok) {
                    alert('Dodano do koszyka!');
                } else {
                    const error = await response.json();
                    alert(error.error || 'Wystąpił błąd');
                }
            } catch (error) {
                console.error('Błąd:', error);
                alert('Wystąpił błąd podczas dodawania do koszyka');
            }
        });
    } catch (error) {
        console.error('Błąd:', error);
        bookDetails.innerHTML = `
            <div class="col-12 text-center py-5">
                <h2 class="text-danger">Błąd ładowania książki</h2>
                <p>${error.message}</p>
                <a href="/" class="btn btn-gothic mt-3">Powrót do strony głównej</a>
            </div>
        `;
    }
});

document.querySelector('button').addEventListener('click', async () => {
    try {
        const response = await fetch(`/api/add-to-cart`, {
            method: 'POST',
            headers: getAuthHeaders(),
            body: JSON.stringify({
                book_id: new URLSearchParams(window.location.search).get('id'),
                quantity: 1
            })
        });
        
        if (response.status === 401) {
            window.location.href = '/login.html';
            return;
        }
        
        // ... reszta obsługi
    } catch (error) {
        console.error('Error:', error);
    }
});
