document.addEventListener('DOMContentLoaded', async () => {
    try {
        const token = localStorage.getItem('token');
        if (!token) {
            window.location.href = '/login.html';
            return;
        }

        const response = await fetch('/api/order-history', {
            headers: { 'Authorization': `Bearer ${token}` }
        });
        
        if (!response.ok) throw new Error('Błąd ładowania historii');
        
        const orders = await response.json();
        const container = document.getElementById('order-history');
        container.innerHTML = '';

        orders.forEach(order => {
            const orderDate = new Date(order.data_zamowienia).toLocaleDateString();
            const orderHTML = `
                <div class="card dark-card mb-3">
                    <div class="card-body">
                        <h5 class="card-title">Zamówienie #${order.id}</h5>
                        <p class="card-text">Data: ${orderDate}</p>
                        <p class="card-text">Suma: ${order.suma_totalna} PLN</p>
                        <p class="card-text">Status: ${order.status || 'Przyjęto do realizacji'}</p>
                    </div>
                </div>
            `;
            container.insertAdjacentHTML('beforeend', orderHTML);
        });

    } catch (error) {
        console.error('Error:', error);
        alert('Nie udało się załadować historii zamówień');
    }
});
